VDSGen
======

A command line tool for creating virtual dataset HDF5 files from a set of HDF5 files.


    |Build Status|  |Coverage Status|  |Code Health|

.. |Build Status| image:: https://api.travis-ci.org/dls-controls/vds-gen.svg
    :target: https://travis-ci.org/dls-controls/vds-gen
.. |Coverage Status| image:: https://coveralls.io/repos/github/dls-controls/vds-gen/badge.svg?branch=master
    :target: https://coveralls.io/github/dls-controls/vds-gen?branch=master
.. |Code Health| image:: https://landscape.io/github/dls-controls/vds-gen/master/landscape.svg?style=flat
    :target: https://landscape.io/github/dls-controls/vds-gen/master